MultiRowReadCap

Trait MultiRowReadCap 

pub trait MultiRowReadCap<F: PrimeField, CIx: ColumnIndexer<usize>>
where Self: ColWriteCap<F, CIx>,
{ // Required methods fn read_row_column(&mut self, row: usize, col: CIx) -> Self::Variable; fn next_row(&mut self); fn curr_row(&self) -> usize; }
Capability for reading and moving forward in a multirow fashion. Holds a “current” row that can be moved forward with next_row. The ColWriteCap and ColAccessCap reason in terms of current row. The two other methods can be used to read/write previous.

Required Methods

fn read_row_column(&mut self, row: usize, col: CIx) -> Self::Variable

Read value from a (row,column) position.

fn next_row(&mut self)

Progresses to the next row.

fn curr_row(&self) -> usize

Returns the current row.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, F: PrimeField, CIx: ColumnIndexer<usize>, Env1: MultiRowReadCap<F, CIx>, L> MultiRowReadCap<F, CIx> for SubEnvLookup<'a, F, CIx, Env1, L>

Source

impl<F: PrimeField, CIx: ColumnIndexer<usize>, const N_WIT: usize, const N_REL: usize, const N_DSEL: usize, const N_FSEL: usize, LT: LookupTableID> MultiRowReadCap<F, CIx> for WitnessBuilderEnv<F, CIx, N_WIT, N_REL, N_DSEL, N_FSEL, LT>